searchData={"content_type":"text/markdown","items":[{"doc":"Runtime interface to manipulate on-disk secrets.","ref":"SecretVault.html","title":"SecretVault","type":"module"},{"doc":"Remove secret `name` from the vault specified by the `config` from disk.\n\nExample:\n    iex> config = SecretVault.Config.test_config\n    iex> SecretVault.put(config, \"db_password\", \"super_secret_password\")\n    iex> SecretVault.delete(config, \"db_password\")\n    iex> SecretVault.fetch(config, \"db_password\")\n    {:error, {:secret_not_found, \"db_password\", \"test\"}}","ref":"SecretVault.html#delete/2","title":"SecretVault.delete/2","type":"function"},{"doc":"Tells whether the secret `name` exists.\n\nExample:\n    iex> config = SecretVault.Config.test_config\n    iex> SecretVault.put(config, \"db_password\", \"super_secret_password\")\n    iex> SecretVault.exists?(config, \"db_password\")\n    true\n    iex> SecretVault.exists?(config, \"non_present_password\")\n    false","ref":"SecretVault.html#exists?/2","title":"SecretVault.exists?/2","type":"function"},{"doc":"Fetch a clear text value of the secret `name` using the `config`. Reads\na data from disk storage, decrypts it, and returns the result of an operation\nin an \"either\" manner.\n\nExample:\n    iex> config = SecretVault.Config.test_config\n    iex> SecretVault.put(config, \"db_password\", \"super_secret_password\")\n    iex> SecretVault.fetch(config, \"db_password\")\n    {:ok, \"super_secret_password\"}\n    iex> SecretVault.fetch(config, \"non_present_password\")\n    {:error, {:secret_not_found, \"non_present_password\", \"test\"}}","ref":"SecretVault.html#fetch/2","title":"SecretVault.fetch/2","type":"function"},{"doc":"Fetch a clear text value of the secret `name` using the `config`.\n\nFetch a clear text value of the secret `name` using the `config`. Reads\na data from disk storage, decrypts it, and returns the decrypted data or\nraises if no secret with the `name` found.\n\nExample:\n    iex> config = SecretVault.Config.test_config\n    iex> SecretVault.put(config, \"db_password\", \"super_secret_password\")\n    iex> SecretVault.fetch!(config, \"db_password\")\n    \"super_secret_password\"","ref":"SecretVault.html#fetch!/2","title":"SecretVault.fetch!/2","type":"function"},{"doc":"Asynchronously fetches all secrets from the vault specified by the `config` from disk.\nThis function returns a map or error in \"either\" manner.\n\nExample:\n    iex> config = SecretVault.Config.test_config\n    iex> SecretVault.put(config, \"db_password\", \"super_secret_password\")\n    iex> SecretVault.put(config, \"admin_password\", \"another_password\")\n    iex> SecretVault.fetch_all(config)\n    {:ok, %{\"db_password\" => \"super_secret_password\", \"admin_password\" => \"another_password\"}}","ref":"SecretVault.html#fetch_all/1","title":"SecretVault.fetch_all/1","type":"function"},{"doc":"Get a clear text value of the secret `name` using the `config`. Reads\na data from disk storage, decrypts it, and returns the default if secret was not found.\n\nExample:\n    iex> config = SecretVault.Config.test_config\n    iex> SecretVault.put(config, \"db_password\", \"super_secret_password\")\n    iex> SecretVault.get(config, \"db_password\")\n    \"super_secret_password\"\n    iex> SecretVault.get(config, \"non_present_password\")\n    \"\"","ref":"SecretVault.html#get/3","title":"SecretVault.get/3","type":"function"},{"doc":"Show all secrets' names available. It reads secrets from directory specified by `config`\nand retruns a list of names with no particular order.\n\nExample:\n    iex> config = SecretVault.Config.test_config\n    iex> SecretVault.put(config, \"db_password\", \"super_secret_password\")\n    iex> SecretVault.put(config, \"admin_password\", \"another_password\")\n    iex> {:ok, names} = SecretVault.list(config)\n    iex> \"db_password\" in names\n    true\n    iex> \"admin_password\" in names\n    true","ref":"SecretVault.html#list/1","title":"SecretVault.list/1","type":"function"},{"doc":"Put `data` as a value of the secret `name` using the `config`. This function\nwrites encrypted data to the disk, therefore use this with caution. If you\nwant to write data in runtime, it is recommended to create singleton\nprocess to perform mutating operations\n\nExample:\n    iex> config = SecretVault.Config.test_config\n    iex> SecretVault.put(config, \"db_password\", \"super_secret_password\")\n    iex> SecretVault.get(config, \"db_password\")\n    \"super_secret_password\"","ref":"SecretVault.html#put/3","title":"SecretVault.put/3","type":"function"},{"doc":"Like `SecretVault.runtime_secret!/3` but accepts default value when secret is not found\nas the third parameter.","ref":"SecretVault.html#runtime_secret/4","title":"SecretVault.runtime_secret/4","type":"macro"},{"doc":"Helper macro for getting secrets in `config/runtime.exs` file.","ref":"SecretVault.html#runtime_secret!/3","title":"SecretVault.runtime_secret!/3","type":"macro"},{"doc":"```\n# in `config/runtime.exs`\nimport Config\nimport SecretVault, only: [runtime_secret!: 2]\n\nconfig :my_app, MyApp.Repo,\n  password: runtime_secret!(:my_app, \"database_password\")\n```\n\nFor a list of available options, see `t:SecretVault.Config.config_option/0`","ref":"SecretVault.html#runtime_secret!/3-example","title":"Example - SecretVault.runtime_secret!/3","type":"macro"},{"doc":"Name of a secret","ref":"SecretVault.html#t:name/0","title":"SecretVault.name/0","type":"type"},{"doc":"- `:unknown_prefix` means that directory with secrets is not present on disk\n- `:secret_not_found` means that secret file itself is not present","ref":"SecretVault.html#t:reason/0","title":"SecretVault.reason/0","type":"type"},{"doc":"Binary value you want to store in secret.\nTo store arbitary structures, try usings `:erlang.term_to_binary/2`","ref":"SecretVault.html#t:value/0","title":"SecretVault.value/0","type":"type"},{"doc":"Configuration for a `SecretVault` vault. This configuration\ndefines ciphers, their options, holds simmetric encryption key\nand path to the vault.\n\nYou can set configuration as plain values like\n```elixir\nconfig :my_app, :secret_vault,\n  default: [password: \"super secret password\"]\n```\n\nOr like\n```elixir\nconfig :my_app, :secret_vault,\n  default: [password: {System, :get_env, \"SUPER_SECRET_PASSWORD\"}]\n```\nTo fetch password in runtime with specified module function arity","ref":"SecretVault.Config.html","title":"SecretVault.Config","type":"module"},{"doc":"Return list of options available for config.","ref":"SecretVault.Config.html#available_options/0","title":"SecretVault.Config.available_options/0","type":"function"},{"doc":"Same as `fetch_from_env/3`, but passes `env` authomatically.\nFetch config from the application configuration (e.g. in\n`confix.exs`).\n\n`otp_app` is the current OTP application name.\n`prefix` must be one of the configured prefixes.","ref":"SecretVault.Config.html#fetch_from_current_env/3","title":"SecretVault.Config.fetch_from_current_env/3","type":"function"},{"doc":"Creates a struct that keeps configuration data for the storage.\n\n`app_name` is an OTP application name for the app you want to\nkeep secrets for.","ref":"SecretVault.Config.html#new/2","title":"SecretVault.Config.new/2","type":"function"},{"doc":"A module implementing `SecretVault.EncryptionProvider` behaviour.","ref":"SecretVault.Config.html#t:cipher/0","title":"SecretVault.Config.cipher/0","type":"type"},{"doc":"Options for specified cipher.","ref":"SecretVault.Config.html#t:cipher_opts/0","title":"SecretVault.Config.cipher_opts/0","type":"type"},{"doc":"Options to set for a config.","ref":"SecretVault.Config.html#t:config_option/0","title":"SecretVault.Config.config_option/0","type":"type"},{"doc":"Simmetric key for cipher","ref":"SecretVault.Config.html#t:key/0","title":"SecretVault.Config.key/0","type":"type"},{"doc":"A module implementing `SecretVault.KeyDerivation`","ref":"SecretVault.Config.html#t:key_derivation/0","title":"SecretVault.Config.key_derivation/0","type":"type"},{"doc":"Options for specified key derivation function.","ref":"SecretVault.Config.html#t:key_derivation_opts/0","title":"SecretVault.Config.key_derivation_opts/0","type":"type"},{"doc":"Plain string password.","ref":"SecretVault.Config.html#t:password/0","title":"SecretVault.Config.password/0","type":"type"},{"doc":"Path prefix for your secrets in priv directory.\n\nIt's usefull when you want to have more than one secret storage.\nDefaults to `secrets`.","ref":"SecretVault.Config.html#t:prefix/0","title":"SecretVault.Config.prefix/0","type":"type"},{"doc":"Priv path. Use it only when you wan't to specify it by hands.","ref":"SecretVault.Config.html#t:priv_path/0","title":"SecretVault.Config.priv_path/0","type":"type"},{"doc":"","ref":"SecretVault.Config.html#t:t/0","title":"SecretVault.Config.t/0","type":"type"},{"doc":"Module with helpers to store secrets in various storages.","ref":"SecretVault.Storage.html","title":"SecretVault.Storage","type":"module"},{"doc":"All functions in this module accept an optional argument:\n[`transform`](`t:transform_function/0`) which is a function to\ntransform secret values. This may be helpful if your storage doesn't\nsupport string keys (or may be you don't want to deal with them) or\nif you just want to transform the data somehow.","ref":"SecretVault.Storage.html#module-transform-function","title":"Transform function - SecretVault.Storage","type":"module"},{"doc":"Stores secrets in a `Application` env using `Application.put_env/4`.\n\nStored secrets can be accessed with\n`Application.fetch_env!(application_name, :secret_storage)[name]`.","ref":"SecretVault.Storage.html#to_application_env/4","title":"SecretVault.Storage.to_application_env/4","type":"function"},{"doc":"iex> config = SecretVault.Config.test_config()\n    iex> SecretVault.put(config, \"name\", \"value\")\n    iex> to_application_env(config, :secret_vault)\n    iex> Application.fetch_env!(:secret_vault, :secret_storage)[\"name\"]\n    \"value\"","ref":"SecretVault.Storage.html#to_application_env/4-example","title":"Example - SecretVault.Storage.to_application_env/4","type":"function"},{"doc":"Stores secrets in a `:ets` table using `:ets.insert`.\n\nStored secrets can be accessed with `:ets.lookup(table, name)` or\nother `:ets` functions.","ref":"SecretVault.Storage.html#to_ets/3","title":"SecretVault.Storage.to_ets/3","type":"function"},{"doc":"iex> config = SecretVault.Config.test_config()\n    iex> SecretVault.put(config, \"name\", \"value\")\n    iex> table = :ets.new(:example_table, [:set, :protected])\n    iex> to_ets(config, table)\n    iex> :ets.lookup(table, \"name\")\n    [{\"name\", \"value\"}]","ref":"SecretVault.Storage.html#to_ets/3-example","title":"Example - SecretVault.Storage.to_ets/3","type":"function"},{"doc":"Stores secrets in a `:persistent_term`.\n\nStored secrets can be accessed with `:persistent_term.get(name)`","ref":"SecretVault.Storage.html#to_persistent_term/2","title":"SecretVault.Storage.to_persistent_term/2","type":"function"},{"doc":"iex> config = SecretVault.Config.test_config()\n    iex> SecretVault.put(config, \"name\", \"value\")\n    iex> to_persistent_term(config)\n    iex> :persistent_term.get(\"name\")\n    \"value\"","ref":"SecretVault.Storage.html#to_persistent_term/2-example","title":"Example - SecretVault.Storage.to_persistent_term/2","type":"function"},{"doc":"Stores secrets in a `Application` env using `Process.put/2`.\n\nStored secrets can be accessed with `Process.get(name)`","ref":"SecretVault.Storage.html#to_proccess_dictionary/2","title":"SecretVault.Storage.to_proccess_dictionary/2","type":"function"},{"doc":"iex> config = SecretVault.Config.test_config()\n    iex> SecretVault.put(config, \"name\", \"value\")\n    iex> to_proccess_dictionary(config)\n    iex> Process.get(\"name\")\n    \"value\"","ref":"SecretVault.Storage.html#to_proccess_dictionary/2-example","title":"Example - SecretVault.Storage.to_proccess_dictionary/2","type":"function"},{"doc":"A function that transforms values fetched from the secret vault.","ref":"SecretVault.Storage.html#t:transform_function/0","title":"SecretVault.Storage.transform_function/0","type":"type"},{"doc":"Performs audit of passwords, detect duplicates and weak passwords.\nExits with exit code `1` if at least one check fails.","ref":"Mix.Tasks.Scr.Audit.html","title":"mix scr.audit","type":"task"},{"doc":"$ mix scr.audit","ref":"Mix.Tasks.Scr.Audit.html#module-usage","title":"Usage - mix scr.audit","type":"task"},{"doc":"- `--no-similarity` - to disable password similarity check\n- `--digits` - to enforce passwords having at least one digit\n- `--uppercase` - to enforce uppercase letters in password\n- `--mix-length=N` - to enforce minimul length requirement\n- `--no-plaintext` - to disable checking for unencrypted passwords","ref":"Mix.Tasks.Scr.Audit.html#module-check-options","title":"Check options - mix scr.audit","type":"task"},{"doc":"You can override config options by providing command line arguments.\n\n- `:cipher` - specify a cipher module to use;\n- `:priv_path` - path to `priv` directory;\n- `:prefix` - prefix to use (defaults to `default`);\n- `:password` - use a password that's different from the one that's\n  configured.","ref":"Mix.Tasks.Scr.Audit.html#module-config-override","title":"Config override - mix scr.audit","type":"task"},{"doc":"","ref":"Mix.Tasks.Scr.Audit.html#run/1","title":"Mix.Tasks.Scr.Audit.run/1","type":"function"},{"doc":"Creates a new secret in the specified environment and under\nthe specified name using your preffered editor.\n\nIt uses configuration of the current application to retrieve the\nkeys and other options.","ref":"Mix.Tasks.Scr.Create.html","title":"mix scr.create","type":"task"},{"doc":"$ mix scr.create prod database_url","ref":"Mix.Tasks.Scr.Create.html#module-usage","title":"Usage - mix scr.create","type":"task"},{"doc":"You can override config options by providing command line arguments.\n\n- `:cipher` - specify a cipher module to use;\n- `:priv_path` - path to `priv` directory;\n- `:prefix` - prefix to use (defaults to `default`);\n- `:password` - use a password that's different from the one that's\n  configured.","ref":"Mix.Tasks.Scr.Create.html#module-config-override","title":"Config override - mix scr.create","type":"task"},{"doc":"Creates a new secret in the specified environment and under the\nspecified name using your preffered editor.\n\nIt uses configuration of the current application to retrieve the\nkeys and so on.","ref":"Mix.Tasks.Scr.Edit.html","title":"mix scr.edit","type":"task"},{"doc":"$ mix scr.edit prod database_url","ref":"Mix.Tasks.Scr.Edit.html#module-usage","title":"Usage - mix scr.edit","type":"task"},{"doc":"You can override config options by providing command line arguments.\n\n- `:cipher` - specify a cipher to use;\n- `:priv_path` - path to `priv` directory;\n- `:prefix` - prefix to use (defaults to `default`);\n- `:password` - use a password that's different from the one that's\n  configured.","ref":"Mix.Tasks.Scr.Edit.html#module-config-override","title":"Config override - mix scr.edit","type":"task"},{"doc":"Creates a new secret in the specified environment and under the\nspecified name.\n\nIt uses configuration of the current application to retrieve the\nkeys and so on.","ref":"Mix.Tasks.Scr.Insert.html","title":"mix scr.insert","type":"task"},{"doc":"$ mix scr.insert prod database_password \"My Super Secret Password\"","ref":"Mix.Tasks.Scr.Insert.html#module-usage","title":"Usage - mix scr.insert","type":"task"},{"doc":"You can override config options by providing command line arguments.\n\n- `:cipher` - specify a cipher to use;\n- `:priv_path` - path to `priv` directory;\n- `:prefix` - prefix to use (defaults to `default`);\n- `:password` - use a password that's different from the one that's\n  configured.","ref":"Mix.Tasks.Scr.Insert.html#module-config-override","title":"Config override - mix scr.insert","type":"task"},{"doc":"Shows an existing secret in the specified environment and under\nthe specified name.\n\nIf the name of a secret is not provided, it lists all the existing\nsecrets.\n\nIt uses configuration of the current application to retrieve the\nkeys and so on.","ref":"Mix.Tasks.Scr.Show.html","title":"mix scr.show","type":"task"},{"doc":"To show the secret use\n\n    $ mix scr.show prod database_url\n\nIf you want to list all the available secrets for the environment,\nyou can run\n\n    $ mix scr.show prod","ref":"Mix.Tasks.Scr.Show.html#module-usage","title":"Usage - mix scr.show","type":"task"},{"doc":"You can override config options by providing command line arguments.\n\n- `:cipher` - specify a cipher to use;\n- `:priv_path` - path to `priv` directory;\n- `:prefix` - prefix to use (defaults to `default`);\n- `:password` - use a password that's different from the one that's\n  configured.","ref":"Mix.Tasks.Scr.Show.html#module-config-override","title":"Config override - mix scr.show","type":"task"},{"doc":"Provides an interface to implement encryption methods.\n\nSee `SecretVault.Cipher.ErlangCrypto` implementation for more\ndetails.","ref":"SecretVault.Cipher.html","title":"SecretVault.Cipher","type":"behaviour"},{"doc":"Decrypt the `cypher_text` with the `key` used to get it.\n\nIf key is invalid, `:invalid_key` error is returned. If\ninappropriate text is passed as `cypher_text`, `Cipher.Error` is\nraised.","ref":"SecretVault.Cipher.html#c:decrypt/3","title":"SecretVault.Cipher.decrypt/3","type":"callback"},{"doc":"Encrypt the `plain_text` with the `key`.","ref":"SecretVault.Cipher.html#c:encrypt/3","title":"SecretVault.Cipher.encrypt/3","type":"callback"},{"doc":"Serialize encryption metadata end a ciphertext into a single binary.\n\nThis is a helper function to prepare the data to be written on the\ndisk.","ref":"SecretVault.Cipher.html#pack/3","title":"SecretVault.Cipher.pack/3","type":"function"},{"doc":"iex> cipher = \"MyNewCipher\"\n    ...> algorithm = \"default\"\n    ...> ciphertext = \"testtest\"\n    ...> pack(cipher, algorithm, [ciphertext])\n    \"MyNewCipher;default;7465737474657374\"","ref":"SecretVault.Cipher.html#pack/3-example","title":"Example - SecretVault.Cipher.pack/3","type":"function"},{"doc":"Deserialize `pack/3`'ed data.","ref":"SecretVault.Cipher.html#unpack!/2","title":"SecretVault.Cipher.unpack!/2","type":"function"},{"doc":"iex> cipher = \"MyNewCipher\"\n    iex> serialized = \"MyNewCipher;default;7465737474657374\"\n    iex> unpack!(cipher, serialized)\n    [\"default\", \"testtest\"]","ref":"SecretVault.Cipher.html#unpack!/2-example","title":"Example - SecretVault.Cipher.unpack!/2","type":"function"},{"doc":"Binary blob that contains encrypted data.","ref":"SecretVault.Cipher.html#t:cypher_text/0","title":"SecretVault.Cipher.cypher_text/0","type":"type"},{"doc":"A key for symetric encryption algorithm as a binary.","ref":"SecretVault.Cipher.html#t:key/0","title":"SecretVault.Cipher.key/0","type":"type"},{"doc":"Binary blob that contains decrypted data.","ref":"SecretVault.Cipher.html#t:plain_text/0","title":"SecretVault.Cipher.plain_text/0","type":"type"},{"doc":"`SecretVault.Cipher` implementation which uses `:crypto` module.\n\nIt is enabled by default and it the recommended cipher to use.\nAs for now it uses `:aes_256_gcm` mode as default and the only available cipher.","ref":"SecretVault.Cipher.ErlangCrypto.html","title":"SecretVault.Cipher.ErlangCrypto","type":"module"},{"doc":"Stores passwords in plaintext.\n\nImplements `SecretVault.Cipher`.\n\n> ##","ref":"SecretVault.Cipher.Plaintext.html","title":"SecretVault.Cipher.Plaintext","type":"module"},{"doc":">\n> This cipher is insecure and it is supposed to be used only in testing\n> or in self encrypting filesystems.","ref":"SecretVault.Cipher.Plaintext.html#module-warning-warning","title":"Warning {: .warning } - SecretVault.Cipher.Plaintext","type":"module"},{"doc":"PKCS #2 PBKDF2 (Password-Based Key Derivation Function 2).\n\nImplements `SecretVault.KeyDerivation`.","ref":"SecretVault.KDFs.PBKDF2.html","title":"SecretVault.KDFs.PBKDF2","type":"module"},{"doc":"Call the PBKDF function.","ref":"SecretVault.KDFs.PBKDF2.html#kdf/2","title":"SecretVault.KDFs.PBKDF2.kdf/2","type":"function"},{"doc":"- `:key_length` - set the key length (default is 32);\n- `:iterations_count` - set the count of iterations (default is 5).","ref":"SecretVault.KDFs.PBKDF2.html#kdf/2-options","title":"Options - SecretVault.KDFs.PBKDF2.kdf/2","type":"function"},{"doc":"","ref":"SecretVault.KDFs.PBKDF2.html#t:option/0","title":"SecretVault.KDFs.PBKDF2.option/0","type":"type"},{"doc":"Defines an interface to derive a key from user-defined password.","ref":"SecretVault.KeyDerivation.html","title":"SecretVault.KeyDerivation","type":"behaviour"},{"doc":"Return binary derived from `user_input`.","ref":"SecretVault.KeyDerivation.html#c:kdf/2","title":"SecretVault.KeyDerivation.kdf/2","type":"callback"},{"doc":"This exception gets raised when some error occurs during decoding of an encrypted secret.","ref":"SecretVault.Cipher.Error.html","title":"SecretVault.Cipher.Error","type":"exception"},{"doc":"Exception for bang functions in `SecretVault`.","ref":"SecretVault.Error.html","title":"SecretVault.Error","type":"exception"},{"doc":"# SecretVault 🔒\n\nAll-in-one solution for storing your Elixir application secrets inside the repository.","ref":"readme.html","title":"SecretVault 🔒","type":"extras"},{"doc":"* **Standalone**. No dependencies on external binaries.\n* **Secure**. Uses [aes256gcm](https://en.wikipedia.org/wiki/Galois/Counter_Mode) cipher by default. Detects weak and similar passwords with `mix scr.audit` task.\n* **Developer friendly**. You can use `mix scr.*` tasks to create or\n  edit secrets in your favourit editor. Or you can use simple\n  coreutils like `mv`, `rm`, `cp`.\n* **Easy to use**. Documatation is rich, errors are descriptive and\n  tutorials take no more than 5 minutes to read.\n* **VCS friendly**. `SecretVault` stores secrets in separate files,\n  thus makes it easily to track in VCS.\n* **Mix friendly**. `SecretVault` enforces separation of secrets for\n  different environments.\n* **Extensible**. You can connect your own ciphers, vaults or key\n  derivation functions.\n* **OTP Compatible**. Uses modern OTP 24 key derivation functions, or\n  fallbacks to elixir implementation on lower OTP versions.","ref":"readme.html#features","title":"Features - SecretVault 🔒","type":"extras"},{"doc":"Check out this 5 minutes [usage tutorial](usage.md) for basics and useful links.","ref":"readme.html#usage","title":"Usage - SecretVault 🔒","type":"extras"},{"doc":"Just add it to the list of dependencies like\n\n```elixir\ndef deps do\n  [\n    {:secret_vault, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - SecretVault 🔒","type":"extras"},{"doc":"If you want to contribute to the project or just want to test it\nlocaly (not as a dependency), you'll need to create `config/config.exs`\nfile with following content.\n\n```elixir\nconfig :secret_vault, :secret_vault,\n  default: [password: \"Some super secret\"]\n```\n\n---\n\n#","ref":"readme.html#hacking","title":"Hacking - SecretVault 🔒","type":"extras"},{"doc":"@benonymus -- for battle testing the project and giving the idea for `runtime_secret` macro","ref":"readme.html#thanks","title":"Thanks - SecretVault 🔒","type":"extras"},{"doc":"# Changelog\n\n#","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* Fixes lstat bug on non-ext4 filesystems (like btrfs)\n\n#","ref":"changelog.html#1-2-2","title":"1.2.2 - Changelog","type":"extras"},{"doc":"* Ignores hidden files (those starting with `.`) in secrets directory\n\n#","ref":"changelog.html#1-2-1","title":"1.2.1 - Changelog","type":"extras"},{"doc":"* Typo in guide fix\n\n#","ref":"changelog.html#1-2-0","title":"1.2.0 - Changelog","type":"extras"},{"doc":"* Introduces `runtime_secret` family of functions\n\n#","ref":"changelog.html#1-1-0","title":"1.1.0 - Changelog","type":"extras"},{"doc":"* Fixes the bug with wrong env detected in `fetch_from_current_env`\n\n# 1.0.0 initial version","ref":"changelog.html#1-0-1","title":"1.0.1 - Changelog","type":"extras"},{"doc":"# Mix release integration\n\n`mix release` allows user to make an aritfact of the application to ease further distribution.\nThis leads to several limitations which can be solved using SecretVault.","ref":"releases.html","title":"Mix release integration","type":"extras"},{"doc":"Specify `secret_vault` or your stub application for secrets as permanent in `mix.exs`. For example:\n```elixir\nreleases: [\n  demo: [\n    applications: [\n      # For plain apps\n      secret_vault: :permanent,\n\n      # Or for stub apps (like in umbrella tutorial)\n      secret_vault_stub: :permanent\n    ]\n  ]\n]\n```","ref":"releases.html#release-configuration","title":"Release configuration - Mix release integration","type":"extras"},{"doc":"Building Elixir application in releases, generates `sys.config` from compile time configuration, so\ndefault approach with password in `config.exs` will have the password in plain form in `sys.config`.\nTo avoid this, you must specify secret to be lazyly fetched in runtime.\n\nSo, in your `config/config.exs`:\n```elixir\nconfig :my_app, :secret_vault,\n  default: [password: {System, :get_env, \"VARIABLE_WITH_PASSWORD\"}]\n```\n\nAnd in your `config/runtime.exs`:\n```elixir\nimport SecretVault, only: [runtime_secret: 2]\n\nconfig :my_app, :database_password, runtime_secret(:my_app, \"database_password\")\n```","ref":"releases.html#runtime-configuration","title":"Runtime configuration - Mix release integration","type":"extras"},{"doc":"# Umbrella tutorial\n\nThis is a 6 minutes `SecretVault` tutorial that shows how to install\nand configure `SecretVault` for umbrella applications.","ref":"umbrella.html","title":"Umbrella tutorial","type":"extras"},{"doc":"Create a separate dummy application in your apps directory like\n```sh\n$ cd apps\n$ mix new secret_store\n$ cd secret_store\n```\n\nRemove lib and test directories and chagne README.md to reflect that\nthis application is used solely for secret management\n\n```sh\n$ rm -rf lib test\n$ mkdir priv\n$ echo \"# SecretStore\\n\\nDummy storage for secrets\" > README.md\n```","ref":"umbrella.html#setup","title":"Setup - Umbrella tutorial","type":"extras"},{"doc":"Just add it into your `SecretStore`'s dependencies like\n```elixir\ndefp deps do\n  [\n    {:secret_vault, \"~> 1.0\"}\n  ]\nend\n```","ref":"umbrella.html#install","title":"Install - Umbrella tutorial","type":"extras"},{"doc":"Configuration is straightforward. Minimal configuration would look\nlike this:\n\n```elixir\nimport Config\n\nconfig :secret_store, :secret_vault,\n  default: [password: System.fetch_env!(\"SECRET_VAULT_PASSWORD\")]\n\n# Here `default` is a name of a default prefix. Prefixes work like namespaces for secrets.\n```\n\n\nYou can provide options other than\n`password`. To see a full list of those check out the\n`SecretVault.Config.new/2` documentation.\n\n> #","ref":"umbrella.html#configure","title":"Configure - Umbrella tutorial","type":"extras"},{"doc":">\n> Each `MIX_ENV` will have it's own separate vault, so don't use\n> prefixes to separate envs.","ref":"umbrella.html#note-info","title":"Note {: .info } - Umbrella tutorial","type":"extras"},{"doc":"To create a secret during development, you can use one of many secret\ncreating tasks available. But do not forget to provide the enviroment\nvariable with the password which we specified above.\n\nFor example (inside `apps/secret_store`),\n\n```sh\n$ export SECRET_VAULT_PASSWORD=\"password\" # Don't forget to change the password value\n$ mix scr.insert dev database_password \"My Super Secret Password\"\n```\n\nOr, to be able to write a password in your favourite editor, use\n\n```sh\n$ mix scr.create dev database_password\n```\n\nHere `dev` defines the `MIX_ENV` for which you'd like to create a\nsecret. And `database_password` is a name of the secret. These exact\ncommands will create a secret in\n`priv/dev/default/database_password.vault_secret`. Each secret is\nwritten onto it's own file in vault directory in `priv`. This plays\nnice with version control systems and simplifies the user interface.\n\n> #","ref":"umbrella.html#create-secrets","title":"Create secrets - Umbrella tutorial","type":"extras"},{"doc":">\n> Each secret is written into it's own file with `.vault_secret`\n> extension. Therefore, secrets' names must be suitable file names.","ref":"umbrella.html#note-info","title":"Note {: .info } - Umbrella tutorial","type":"extras"},{"doc":"To edit already created secrets, one can use `mix scr.insert` and `mix\nscr.edit` commands. To delete, rename or copy secrets, one\ncan use regular coreutils like `mv`, `cp`, `rm`, since each secret is\nplaced under the corresponding directory in `priv`. Usually the path\nis `priv/$MIX_ENV/$PREFIX/${SECRET_NAME}.vault_secret`.\n\nFor example, to delete secret which was created in previous step, one\ncould write:\n\n```sh\n$ rm priv/dev/default/database_password.vault_secret\n```\n\nOr to rename a secret:\n```sh\n$ cd priv/dev/default/\n$ mv database_password.vault_secret db_password.vault_secret\n```","ref":"umbrella.html#manipulate-secrets","title":"Manipulate secrets - Umbrella tutorial","type":"extras"},{"doc":"To access and use secrets from `Elixir` application, one first need to\nretrieve the vault configuration. Then, it is recommended to place the\nsecrets into some runtime storage (like `persistent_term`, for\nexample).\n\nSo, regular workflow would look like\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    ...\n    {:ok, config} = SecretVault.Config.fetch_from_current_env(:my_app)\n    SecretVault.Storage.to_persistent_term(config)\n  end\nend\n```\n\nThis will create config from configuration of your application and put\nall decrypted passwords in the `persistent_term`. See\n`SecretVault.Config` and `SecretVault.Storage` for more options.\n\nIf you want to have you options in application env you can specify\nthis in `config.exs`\n\n```elixir\n# in config/config.exs\nimport Config\n\nconfig :secret_store, :secret_vault,\n  default: [password: System.fetch_env!(\"SECRET_VAULT_PASSWORD\")]\n\n# in application.ex start function\n{:ok, config} = SecretVault.Config.fetch_from_current_env(:my_app)\nSecretVault.Storage.to_application_env(config)\n```","ref":"umbrella.html#access-secrets","title":"Access secrets - Umbrella tutorial","type":"extras"},{"doc":"It is a common practice to configure application in configuration scripts like `config/config.exs`, `config/dev.exs` and `config/runtime.exs`. And there are two things\na developer must keep in mind while working with them\n\nFirst of all, you **must not** use compile time configuration scritps (basically everything except `runtime.exs`) for setting values from secrets, since these values will appear in `app.src` file in your `_build` or release ebin directory. Usually, this is not something you can tolerate\n\nSecond, `runtime.exs` config will be called during initialization of your project and the enviroment of the project will be inherited from the enviroment which was during project compilation. This means, that for release created with `MIX_ENV=dev mix release` and called with\n`MIX_ENV=prod myapp start`, secrets (and all other configuration) will be fetched from `dev` enviroment.\n\nSo, to configure secrets in runtime, you can write something like:\n\n```\n# in config/runtime.exs\nimport Config\nimport SecretVault, only: [runtime_secret!: 2]\n\nconfig :secret_store, MyApp.Repo,\n  password: runtime_secret!(:secret_store, \"database_password\")\n```","ref":"umbrella.html#runtime-configuration","title":"Runtime configuration - Umbrella tutorial","type":"extras"},{"doc":"There is no special behaviour for releases. Just `mix release` and\nuse. Don't forget to add `mix scr.audit` task in your `CI` to enforce\nquality of passwords.","ref":"umbrella.html#release","title":"Release - Umbrella tutorial","type":"extras"},{"doc":"# Usage tutorial\n\nThis is a 5 minutes `SecretVault` tutorial that shows how to install\nand configure `SecretVault`, and then create, delete, edit, and access\nsecrets in runtime.","ref":"usage.html","title":"Usage tutorial","type":"extras"},{"doc":"Just add it into your dependencies like\n```elixir\ndefp deps do\n  [\n    {:secret_vault, \"~> 1.0\"}\n  ]\nend\n```","ref":"usage.html#install","title":"Install - Usage tutorial","type":"extras"},{"doc":"Just create a `priv` directory in the root of your project","ref":"usage.html#create-priv-dir","title":"Create priv dir - Usage tutorial","type":"extras"},{"doc":"Configuration is straightforward. Minimal configuration would look\nlike this:\n\n```elixir\nimport Config\n\nconfig :my_app, :secret_vault,\n  default: [password: System.fetch_env!(\"SECRET_VAULT_PASSWORD\")]\n\n# Here `default` is a name of a default prefix. Prefixes work like namespaces for secrets.\n```\n\n\nYou can provide options other than\n`password`. To see a full list of those check out the\n`SecretVault.Config.new/2` documentation.\n\n> #","ref":"usage.html#configure","title":"Configure - Usage tutorial","type":"extras"},{"doc":">\n> Each `MIX_ENV` will have it's own separate vault, so don't use\n> prefixes to separate envs.","ref":"usage.html#note-info","title":"Note {: .info } - Usage tutorial","type":"extras"},{"doc":"To create a secret during development, you can use one of many secret\ncreating tasks available. But do not forget to provide the enviroment\nvariable with the password which we specified above.\n\nFor example,\n\n```sh\n$ export SECRET_VAULT_PASSWORD=\"password\" # Don't forget to change the password value\n$ mix scr.insert dev database_password \"My Super Secret Password\"\n```\n\nOr, to be able to write a password in your favourite editor, use\n\n```sh\n$ mix scr.create dev database_password\n```\n\nHere `dev` defines the `MIX_ENV` for which you'd like to create a\nsecret. And `database_password` is a name of the secret. These exact\ncommands will create a secret in\n`priv/dev/default/database_password.vault_secret`. Each secret is\nwritten onto it's own file in vault directory in `priv`. This plays\nnice with version control systems and simplifies the user interface.\n\n> #","ref":"usage.html#create-secrets","title":"Create secrets - Usage tutorial","type":"extras"},{"doc":">\n> Each secret is written into it's own file with `.vault_secret`\n> extension. Therefore, secrets' names must be suitable file names.","ref":"usage.html#note-info","title":"Note {: .info } - Usage tutorial","type":"extras"},{"doc":"To edit already created secrets, one can use `mix scr.insert` and `mix\nscr.edit` commands. To delete, rename or copy secrets, one\ncan use regular coreutils like `mv`, `cp`, `rm`, since each secret is\nplaced under the corresponding directory in `priv`. Usually the path\nis `priv/$MIX_ENV/$PREFIX/${SECRET_NAME}.vault_secret`.\n\nFor example, to delete secret which was created in previous step, one\ncould write:\n\n```sh\n$ rm priv/dev/default/database_password.vault_secret\n```\n\nOr to rename a secret:\n```sh\n$ cd priv/dev/default/\n$ mv database_password.vault_secret db_password.vault_secret\n```","ref":"usage.html#manipulate-secrets","title":"Manipulate secrets - Usage tutorial","type":"extras"},{"doc":"To access and use secrets from `Elixir` application, one first need to\nretrieve the vault configuration. Then, it is recommended to place the\nsecrets into some runtime storage (like `persistent_term`, for\nexample).\n\nSo, regular workflow would look like\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    ...\n    {:ok, config} = SecretVault.Config.fetch_from_current_env(:my_app)\n    SecretVault.Storage.to_persistent_term(config)\n  end\nend\n```\n\nThis will create config from configuration of your application and put\nall decrypted passwords in the `persistent_term`. See\n`SecretVault.Config` and `SecretVault.Storage` for more options.\n\nIf you want to have you options in application env you can specify\nthis in `config.exs`\n\n```elixir\n# in config/config.exs\nimport Config\n\nconfig :my_app, :secret_vault,\n  default: [password: System.fetch_env!(\"SECRET_VAULT_PASSWORD\")]\n\n# in application.ex start function\n{:ok, config} = SecretVault.Config.fetch_from_current_env(:my_app)\nSecretVault.Storage.to_application_env(config)\n```","ref":"usage.html#access-secrets","title":"Access secrets - Usage tutorial","type":"extras"},{"doc":"It is a common practice to configure application in configuration scripts like `config/config.exs`, `config/dev.exs` and `config/runtime.exs`. And there are two things\na developer must keep in mind while working with them\n\nFirst of all, you **must not** use compile time configuration scritps (basically everything except `runtime.exs`) for setting values from secrets, since these values will appear in `app.src` file in your `_build` or release ebin directory. Usually, this is not something you can tolerate\n\nSecond, `runtime.exs` config will be called during initialization of your project and the enviroment of the project will be inherited from the enviroment which was during project compilation. This means, that for release created with `MIX_ENV=dev mix release` and called with\n`MIX_ENV=prod myapp start`, secrets (and all other configuration) will be fetched from `dev` enviroment.\n\nSo, to configure secrets in runtime, you can write something like:\n\n```\n# in config/runtime.exs\nimport Config\nimport SecretVault, only: [runtime_secret!: 2]\n\nconfig :playground, MyApp.Repo,\n  password: runtime_secret!(:playground, \"database_password\")\n```","ref":"usage.html#runtime-configuration","title":"Runtime configuration - Usage tutorial","type":"extras"},{"doc":"There is no special behaviour for releases. Just `mix release` and\nuse. Don't forget to add `mix scr.audit` task in your `CI` to enforce\nquality of passwords.","ref":"usage.html#release","title":"Release - Usage tutorial","type":"extras"}]}